/*
 * Simulator of MCS51 (uccl.h)
 *
 * Copyright (C) 1999,99 Drotos Daniel, Talker Bt.
 * 
 * To contact author send email to drdani@mazsola.iit.uni-miskolc.hu
 *
 */

/* This file is part of MCS51 simulator: s51.

S51 is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

S51 is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with S51; see the file COPYING.  If not, write to the Free
Software Foundation, 59 Temple Place - Suite 330, Boston, MA
02111-1307, USA. */
/*@1@*/

#ifndef UCCL_HEADER
#define UCCL_HEADER

#include "stypes.h"
#include "pobjcl.h"
#include "hwcl.h"
#include "memcl.h"


/* Abstract microcontroller */

class cl_uc: public cl_base
{
public:
  int type;		// CPU family
  int technology;	// CMOS, HMOS
  int state;		// GO, IDLE, PD

public:
  class cl_sim *sim;

  class cl_list *mems;
  class cl_list *hws;

public:
  cl_uc(class cl_sim *asim);
  ~cl_uc(void);
  virtual int init(void);

  virtual int mk_mem(enum mem_class type);
  virtual long get_mem_size(enum mem_class type);

  virtual ulong read_mem(enum mem_class type, long addr);
  virtual ulong get_mem(enum mem_class type, long addr);
  virtual void write_mem(enum mem_class type, long addr, ulong val);
  virtual void set_mem(enum mem_class type, long addr, ulong val);
  virtual class cl_mem *mem(enum mem_class type);
  virtual uchar *MEM(enum mem_class type);

  virtual void register_hw_read(enum mem_class, long addr, class cl_hw *hw);
  virtual void register_hw_write(enum mem_class, long addr, class cl_hw *hw);

  /* Following fields and virtual methods defined in uc51 I don't have
     energy to redesign them:-( */
public:
  uchar port_pins[3];	// Port pins
public:
  virtual void proc_write(uchar *addr) {}
  virtual void del_inst_at(uint addr) {}
  virtual void set_p_flag(void) {}
  virtual uchar *get_bit(uchar bitaddr) {}
  virtual void eram2xram(void) {} // Dirty hack for 51R
  virtual void xram2eram(void) {}
};


#endif

/* End of uccl.h */
